Python bindings to the Selectel VPC API
=======================================

This is a client for the Selectel VPC API. There is a :doc:`Python API
<usage/library>` (the selvpcclient module), and a :doc:`command-line script
<usage/cli>` (installed as **selvpc**).

Using selvpc
------------

.. toctree::
   :maxdepth: 2

   usage/cli
   usage/library

Developer Guide
---------------

In the Developer Guide, you will find information on selvpc client
lower level programming details.
Also, those rules are common for all OS clients.

.. toctree::
   :maxdepth: 2

   devref/cli_option_guideline
   devref/client_command_extensions

Man Page
--------

.. toctree::
   :maxdepth: 1

   usage/man
